"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const getCSSModuleLocalIdent = require("react-dev-utils/getCSSModuleLocalIdent");
const MiniCssExtractPlugin = require("mini-css-extract-plugin");
const paths_1 = __importDefault(require("./paths"));
const cssRegex = /\.css$/;
const cssModuleRegex = /\.module\.css$/;
const sassRegex = /\.(scss|sass)$/;
const sassModuleRegex = /\.module\.(scss|sass)$/;
const lessRegex = /\.(less|less)$/;
const lessModuleRegex = /\.module\.(less|less)$/;
const getStyleLoaders = (isDev, cssOptions, preProcessor) => {
    const loaders = [
        {
            loader: require.resolve("css-loader"),
            options: cssOptions
        },
        {
            loader: require.resolve("postcss-loader"),
            options: {
                ident: "postcss",
                plugins: () => [
                    require("postcss-flexbugs-fixes"),
                    require("postcss-preset-env")({
                        autoprefixer: {
                            flexbox: "no-2009"
                        },
                        stage: 3
                    })
                ]
            }
        }
    ];
    if (preProcessor) {
        loaders.push(preProcessor);
    }
    if (isDev) {
        loaders.unshift(require.resolve("style-loader"));
    }
    else {
        loaders.unshift({
            loader: MiniCssExtractPlugin.loader
        });
    }
    return loaders;
};
function getBabelConfig() {
    return {
        loader: "babel-loader",
        options: {
            customize: require.resolve("babel-preset-react-app/webpack-overrides"),
            presets: [require.resolve("babel-preset-ers")],
            babelrc: false,
            configFile: false,
            plugins: [
                [
                    "import",
                    {
                        libraryName: "antd",
                        style: true
                    }
                ]
            ],
            cacheDirectory: true,
            cacheCompression: false
        }
    };
}
function default_1(WEBPACKCONFIG, isDev) {
    try {
        WEBPACKCONFIG.module.rules = [
            {
                test: /\.(js|jsx)$/,
                enforce: "pre",
                use: [
                    {
                        options: {
                            formatter: require.resolve("react-dev-utils/eslintFormatter"),
                            eslintPath: require.resolve("eslint")
                        },
                        loader: require.resolve("eslint-loader")
                    }
                ],
                include: paths_1.default.appSrc
            },
            {
                oneOf: [
                    {
                        test: [/\.bmp$/, /\.gif$/, /\.jpe?g$/, /\.png$/],
                        loader: require.resolve("url-loader"),
                        options: {
                            limit: 10000,
                            name: "static/media/[name].[hash:8].[ext]"
                        }
                    },
                    {
                        test: /\.(js|jsx)$/,
                        include: paths_1.default.appSrc,
                        use: [
                            {
                                loader: require.resolve("thread-loader"),
                                options: {
                                    poolTimeout: Infinity
                                }
                            },
                            getBabelConfig()
                        ]
                    },
                    {
                        test: cssRegex,
                        exclude: cssModuleRegex,
                        use: getStyleLoaders(isDev, {
                            importLoaders: 1
                        })
                    },
                    {
                        test: cssModuleRegex,
                        use: getStyleLoaders(isDev, {
                            importLoaders: 1,
                            modules: true,
                            getLocalIdent: getCSSModuleLocalIdent
                        })
                    },
                    {
                        test: sassRegex,
                        exclude: sassModuleRegex,
                        use: getStyleLoaders(isDev, { importLoaders: 2 }, "sass-loader")
                    },
                    {
                        test: sassModuleRegex,
                        use: getStyleLoaders(isDev, {
                            importLoaders: 2,
                            modules: true,
                            getLocalIdent: getCSSModuleLocalIdent
                        }, "sass-loader")
                    },
                    {
                        test: lessRegex,
                        exclude: lessModuleRegex,
                        use: getStyleLoaders(isDev, { importLoaders: 2 }, {
                            loader: require.resolve("less-loader"),
                            options: {
                                javascriptEnabled: true,
                                modifyVars: require(paths_1.default.lessModifyVars)
                            }
                        })
                    },
                    {
                        test: lessModuleRegex,
                        use: getStyleLoaders(isDev, {
                            importLoaders: 2,
                            modules: true,
                            getLocalIdent: getCSSModuleLocalIdent
                        }, {
                            loader: require.resolve("less-loader"),
                            options: {
                                javascriptEnabled: true,
                                modifyVars: require(paths_1.default.lessModifyVars)
                            }
                        })
                    },
                    {
                        exclude: [/\.(js|jsx)$/, /\.html$/, /\.json$/],
                        loader: require.resolve("file-loader"),
                        options: {
                            name: "static/media/[name].[hash:8].[ext]"
                        }
                    }
                ]
            }
        ];
    }
    catch (e) {
        throw new Error(e);
    }
}
exports.default = default_1;
