"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const webpack = require("webpack");
const WebpackBar = require("webpackbar");
const HtmlWebpackPlugin = require("html-webpack-plugin");
const paths_1 = __importDefault(require("./paths"));
function injectPlugins(WEBPACKCONFIG, isDev) {
    if (isDev) {
        WEBPACKCONFIG.plugins = [
            new WebpackBar({
                name: "Panther-web",
                compiledIn: false
            }),
            new HtmlWebpackPlugin({
                inject: true,
                template: paths_1.default.appHtml
            }),
            new (require("react-dev-utils/InlineChunkHtmlPlugin"))(HtmlWebpackPlugin, []),
            new webpack.HotModuleReplacementPlugin(),
            new (require("case-sensitive-paths-webpack-plugin"))(),
            new (require("react-dev-utils/WatchMissingNodeModulesPlugin"))(paths_1.default.appNodeModules),
            new webpack.IgnorePlugin(/^\.\/locale$/, /moment$/)
        ];
    }
    else {
        WEBPACKCONFIG.plugins = [
            new HtmlWebpackPlugin({
                inject: true,
                template: paths_1.default.appHtml,
                minify: {
                    removeComments: true,
                    collapseWhitespace: true,
                    removeRedundantAttributes: true,
                    useShortDoctype: true,
                    removeEmptyAttributes: true,
                    removeStyleLinkTypeAttributes: true,
                    keepClosingSlash: true,
                    minifyJS: true,
                    minifyCSS: true,
                    minifyURLs: true
                }
            }),
            new (require("react-dev-utils/InlineChunkHtmlPlugin"))(HtmlWebpackPlugin, [/runtime~.+[.]js/]),
            new (require("mini-css-extract-plugin"))({
                filename: "static/css/[name].[contenthash:8].css",
                chunkFilename: "static/css/[name].[contenthash:8].chunk.css"
            }),
            new webpack.IgnorePlugin(/^\.\/locale$/, /moment$/),
            new WebpackBar({
                minimal: false,
                name: "Panther-web"
            })
        ];
    }
}
exports.default = injectPlugins;
