"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const injectLoaders_1 = __importDefault(require("./injectLoaders"));
const injectPlugins_1 = __importDefault(require("./injectPlugins"));
const paths_1 = __importDefault(require("./paths"));
const isDev = process.env.NODE_ENV === "development";
const config = {
    mode: (isDev && "development") || "production",
    devtool: (isDev && "cheap-module-source-map") || false,
    bail: !isDev,
    entry: (isDev && [
        require.resolve("react-dev-utils/webpackHotDevClient"),
        paths_1.default.appIndexJs
    ]) || [paths_1.default.appIndexJs],
    output: (isDev && {
        pathinfo: true,
        filename: "static/js/bundle.js",
        chunkFilename: "static/js/[name].chunk.js",
        publicPath: "/",
        devtoolModuleFilenameTemplate: info => path_1.default.resolve(info.absoluteResourcePath).replace(/\\/g, "/")
    }) || {
        path: paths_1.default.appBuild,
        filename: "static/js/[name].[chunkhash:8].js",
        chunkFilename: "static/js/[name].[chunkhash:8].chunk.js",
        publicPath: "/",
        devtoolModuleFilenameTemplate: info => path_1.default.relative(paths_1.default.appSrc, info.absoluteResourcePath).replace(/\\/g, "/")
    },
    optimization: (isDev && {
        splitChunks: {
            chunks: "all",
            name: false
        },
        runtimeChunk: true
    }) || {
        minimizer: [
            new (require("terser-webpack-plugin"))({
                terserOptions: {
                    parse: {
                        ecma: 8
                    },
                    compress: {
                        ecma: 5,
                        warnings: false,
                        comparisons: false
                    },
                    mangle: {
                        safari10: true
                    },
                    output: {
                        ecma: 5,
                        comments: false,
                        ascii_only: true
                    }
                },
                parallel: true,
                cache: true,
                sourceMap: false
            }),
            new (require("optimize-css-assets-webpack-plugin"))({
                cssProcessorOptions: { parser: require("postcss-safe-parser") }
            })
        ],
        splitChunks: {
            chunks: "all",
            name: false
        },
        runtimeChunk: true
    },
    resolve: {
        modules: ["node_modules"],
        extensions: [".js", ".json", ".jsx", ".ts", ".tsx"],
        alias: require(paths_1.default.appAlias),
        plugins: [
            new (require("react-dev-utils/ModuleScopePlugin"))(paths_1.default.appSrc, [
                paths_1.default.appPackageJson
            ])
        ]
    },
    module: {
        strictExportPresence: true,
        rules: []
    },
    plugins: [],
    node: {
        dgram: "empty",
        fs: "empty",
        net: "empty",
        tls: "empty",
        child_process: "empty"
    },
    performance: false
};
injectLoaders_1.default(config, isDev);
injectPlugins_1.default(config, isDev);
exports.default = config;
