"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
process.env.BABEL_ENV = "production";
process.env.NODE_ENV = "production";
process.on("unhandledRejection", err => {
    throw err;
});
const chalk_1 = __importDefault(require("chalk"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const webpack_1 = __importDefault(require("webpack"));
const bfj = require("bfj");
const checkRequiredFiles = require("react-dev-utils/checkRequiredFiles");
const formatWebpackMessages = require("react-dev-utils/formatWebpackMessages");
const FileSizeReporter = require("react-dev-utils/FileSizeReporter");
const printBuildError = require("react-dev-utils/printBuildError");
const webpack_2 = __importDefault(require("../config/webpack"));
const paths_1 = __importDefault(require("../config/paths"));
const measureFileSizesBeforeBuild = FileSizeReporter.measureFileSizesBeforeBuild;
const printFileSizesAfterBuild = FileSizeReporter.printFileSizesAfterBuild;
const useYarn = fs_extra_1.default.existsSync(paths_1.default.yarnLockFile);
const WARN_AFTER_BUNDLE_GZIP_SIZE = 512 * 1024;
const WARN_AFTER_CHUNK_GZIP_SIZE = 1024 * 1024;
const isInteractive = process.stdout.isTTY;
if (!checkRequiredFiles([paths_1.default.appHtml, paths_1.default.appIndexJs])) {
    process.exit(1);
}
const argv = process.argv.slice(2);
const writeStatsJson = argv.indexOf("--stats") !== -1;
const { checkBrowsers } = require("react-dev-utils/browsersHelper");
checkBrowsers(paths_1.default.appPath, isInteractive)
    .then(() => {
    return measureFileSizesBeforeBuild(paths_1.default.appBuild);
})
    .then((previousFileSizes) => {
    fs_extra_1.default.emptyDirSync(paths_1.default.appBuild);
    copyPublicFolder();
    return build(previousFileSizes);
})
    .then(({ stats, previousFileSizes, warnings }) => {
    if (warnings.length) {
        console.log(chalk_1.default.yellow("Compiled with warnings.\n"));
        console.log(warnings.join("\n\n"));
        console.log("\nSearch for the " +
            chalk_1.default.underline(chalk_1.default.yellow("keywords")) +
            " to learn more about each warning.");
        console.log("To ignore, add " +
            chalk_1.default.cyan("// eslint-disable-next-line") +
            " to the line before.\n");
    }
    else {
        console.log(chalk_1.default.green("Compiled successfully.\n"));
    }
    console.log("File sizes after gzip:\n");
    printFileSizesAfterBuild(stats, previousFileSizes, paths_1.default.appBuild, WARN_AFTER_BUNDLE_GZIP_SIZE, WARN_AFTER_CHUNK_GZIP_SIZE);
    process.exit(0);
}, (err) => {
    console.log(chalk_1.default.red("Failed to compile.\n"));
    printBuildError(err);
    process.exit(1);
})
    .catch((err) => {
    if (err && err.message) {
        console.log(err.message);
    }
    process.exit(1);
});
function build(previousFileSizes) {
    const compiler = webpack_1.default(webpack_2.default);
    return new Promise((resolve, reject) => {
        compiler.run((err, stats) => {
            if (err) {
                return reject(err);
            }
            const messages = formatWebpackMessages(stats.toJson({ all: false, warnings: true, errors: true }));
            if (messages.errors.length) {
                if (messages.errors.length > 1) {
                    messages.errors.length = 1;
                }
                return reject(new Error(messages.errors.join("\n\n")));
            }
            if (process.env.CI &&
                (typeof process.env.CI !== "string" ||
                    process.env.CI.toLowerCase() !== "false") &&
                messages.warnings.length) {
                console.log(chalk_1.default.yellow("\nTreating warnings as errors because process.env.CI = true.\n" +
                    "Most CI servers set it automatically.\n"));
                return reject(new Error(messages.warnings.join("\n\n")));
            }
            const resolveArgs = {
                stats,
                previousFileSizes,
                warnings: messages.warnings
            };
            if (writeStatsJson) {
                return bfj
                    .write(paths_1.default.appBuild + "/bundle-stats.json", stats.toJson())
                    .then(() => resolve(resolveArgs))
                    .catch((error) => reject(new Error(error)));
            }
            return resolve(resolveArgs);
        });
    });
}
function copyPublicFolder() {
    fs_extra_1.default.copySync(paths_1.default.appPublic, paths_1.default.appBuild, {
        dereference: true,
        filter: file => file !== paths_1.default.appHtml
    });
}
