"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
process.env.BABEL_ENV = "development";
process.env.NODE_ENV = "development";
process.on("unhandledRejection", err => {
    throw err;
});
const fs_1 = __importDefault(require("fs"));
const chalk_1 = __importDefault(require("chalk"));
const webpack_dev_server_1 = __importDefault(require("webpack-dev-server"));
const webpack = require("webpack");
const clearConsole = require("react-dev-utils/clearConsole");
const checkRequiredFiles = require("react-dev-utils/checkRequiredFiles");
const { choosePort, createCompiler, prepareProxy, prepareUrls } = require("react-dev-utils/WebpackDevServerUtils");
const openBrowser = require("react-dev-utils/openBrowser");
const paths_1 = __importDefault(require("../config/paths"));
const webpack_1 = __importDefault(require("../config/webpack"));
const server_1 = __importDefault(require("../config/server"));
const useYarn = fs_1.default.existsSync(paths_1.default.yarnLockFile);
const isInteractive = process.stdout.isTTY;
if (!checkRequiredFiles([paths_1.default.appHtml, paths_1.default.appIndexJs])) {
    process.exit(1);
}
const DEFAULT_PORT = parseInt(process.env.PORT, 10) || 3000;
const HOST = "0.0.0.0";
const { checkBrowsers } = require("react-dev-utils/browsersHelper");
checkBrowsers(paths_1.default.appPath, isInteractive)
    .then(() => {
    return choosePort(HOST, DEFAULT_PORT);
})
    .then((port) => {
    if (port == null) {
        return;
    }
    const protocol = process.env.HTTPS === "true" ? "https" : "http";
    const appName = require(paths_1.default.appPackageJson).name;
    const urls = prepareUrls(protocol, HOST, port);
    const compiler = createCompiler(webpack, webpack_1.default, appName, urls, useYarn);
    const proxySetting = require(paths_1.default.appPackageJson).proxy;
    const proxyConfig = prepareProxy(proxySetting, paths_1.default.appPublic);
    const serverConfig = server_1.default(proxyConfig, urls.lanUrlForConfig);
    const devServer = new webpack_dev_server_1.default(compiler, serverConfig);
    devServer.listen(port, HOST, err => {
        if (err) {
            return console.log(err);
        }
        if (isInteractive) {
            clearConsole();
        }
        console.log(chalk_1.default.cyan("Starting the development server...\n"));
        openBrowser(urls.localUrlForBrowser);
    });
    ["SIGINT", "SIGTERM"].forEach(function (sig) {
        process.on(sig, function () {
            devServer.close();
            process.exit();
        });
    });
})
    .catch((err) => {
    if (err && err.message) {
        console.log(err.message);
    }
    process.exit(1);
});
